@@ -8,6 +8,7 @@ describe 'basic neutron' do
       pp= <<-EOS
       include openstack_integration
       include openstack_integration::repos
+      include openstack_integration::apache
       include openstack_integration::rabbitmq
       include openstack_integration::mysql
       include openstack_integration::keystone
@@ -26,7 +27,7 @@ describe 'basic neutron' do
 
     describe 'test Neutron OVS agent bridges' do
       it 'should list OVS bridges' do
-        shell("ovs-vsctl show") do |r|
+        command("ovs-vsctl show") do |r|
           expect(r.stdout).to match(/br-int/)
           expect(r.stdout).to match(/br-tun/)
         end
