@@ -5,23 +5,16 @@ describe 'basic neutron_config resource' do
   neutron_files = [ '/etc/neutron/api-paste.ini',
                      '/etc/neutron/neutron.conf',
                      '/etc/neutron/dhcp_agent.ini',
-                     '/etc/neutron/fwaas_driver.ini',
                      '/etc/neutron/l3_agent.ini',
                      '/etc/neutron/metadata_agent.ini',
                      '/etc/neutron/metering_agent.ini',
                      '/etc/neutron/l2gw_plugin.ini',
                      '/etc/neutron/l2gateway_agent.ini',
-                     '/etc/neutron/plugins/cisco/cisco_plugins.ini',
-                     '/etc/neutron/plugins/cisco/credentials.ini',
-                     '/etc/neutron/plugins/cisco/db_conn.ini',
-                     '/etc/neutron/plugins/cisco/l2network_plugin.ini',
                      '/etc/neutron/plugins/linuxbridge/linuxbridge_conf.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf.ini',
                      '/etc/neutron/plugins/nicira/nvp.ini',
                      '/etc/neutron/vpn_agent.ini',
-                     '/etc/neutron/plugins/midonet/midonet.ini',
                      '/etc/neutron/plugins/opencontrail/ContrailPlugin.ini',
-                     '/etc/neutron/plugins/plumgrid/plumgrid.ini',
                      '/etc/neutron/plugins/vmware/nsx.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf_sriov.ini',
                      '/etc/neutron/plugins/ml2/sriov_agent.ini',
@@ -33,25 +26,17 @@ describe 'basic neutron_config resource' do
   File <||> -> Neutron_config <||>
   File <||> -> Neutron_api_paste_ini <||>
   File <||> -> Neutron_dhcp_agent_config <||>
-  File <||> -> Neutron_fwaas_service_config <||>
   File <||> -> Neutron_l3_agent_config <||>
   File <||> -> Neutron_metadata_agent_config <||>
   File <||> -> Neutron_metering_agent_config <||>
-  File <||> -> Neutron_plugin_cisco <||>
-  File <||> -> Neutron_plugin_cisco_credentials <||>
-  File <||> -> Neutron_plugin_cisco_db_conn <||>
-  File <||> -> Neutron_plugin_cisco_l2network <||>
   File <||> -> Neutron_plugin_linuxbridge <||>
   File <||> -> Neutron_plugin_ml2 <||>
   File <||> -> Neutron_plugin_nvp <||>
   File <||> -> Neutron_l2gw_service_config <||>
   File <||> -> Neutron_vpnaas_agent_config <||>
-  File <||> -> Neutron_plugin_midonet <||>
   File <||> -> Neutron_plugin_opencontrail <||>
   File <||> -> Neutron_agent_linuxbridge <||>
   File <||> -> Neutron_agent_ovs <||>
-  File <||> -> Neutron_plugin_plumgrid <||>
-  File <||> -> Neutron_plumlib_plumgrid <||>
   File <||> -> Neutron_plugin_sriov <||>
   File <||> -> Neutron_sriov_agent_config <||>
   File <||> -> Neutron_agent_vpp <||>
@@ -61,35 +46,25 @@ describe 'basic neutron_config resource' do
 
   $neutron_directories = ['/etc/neutron',
                           '/etc/neutron/plugins',
-                          '/etc/neutron/plugins/cisco',
                           '/etc/neutron/plugins/linuxbridge',
                           '/etc/neutron/plugins/ml2',
                           '/etc/neutron/plugins/nicira',
-                          '/etc/neutron/plugins/midonet',
                           '/etc/neutron/plugins/opencontrail',
-                          '/etc/neutron/plugins/plumgrid',
                           '/etc/neutron/plugins/vmware']
 
   $neutron_files = [ '/etc/neutron/api-paste.ini',
                      '/etc/neutron/neutron.conf',
                      '/etc/neutron/dhcp_agent.ini',
-                     '/etc/neutron/fwaas_driver.ini',
                      '/etc/neutron/l3_agent.ini',
                      '/etc/neutron/metadata_agent.ini',
                      '/etc/neutron/metering_agent.ini',
                      '/etc/neutron/l2gw_plugin.ini',
                      '/etc/neutron/l2gateway_agent.ini',
-                     '/etc/neutron/plugins/cisco/cisco_plugins.ini',
-                     '/etc/neutron/plugins/cisco/credentials.ini',
-                     '/etc/neutron/plugins/cisco/db_conn.ini',
-                     '/etc/neutron/plugins/cisco/l2network_plugin.ini',
                      '/etc/neutron/plugins/linuxbridge/linuxbridge_conf.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf.ini',
                      '/etc/neutron/plugins/nicira/nvp.ini',
                      '/etc/neutron/vpn_agent.ini',
-                     '/etc/neutron/plugins/midonet/midonet.ini',
                      '/etc/neutron/plugins/opencontrail/ContrailPlugin.ini',
-                     '/etc/neutron/plugins/plumgrid/plumgrid.ini',
                      '/etc/neutron/plugins/vmware/nsx.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf_sriov.ini',
                      '/etc/neutron/plugins/ml2/sriov_agent.ini',
@@ -156,24 +131,6 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
-  neutron_fwaas_service_config { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_fwaas_service_config { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_fwaas_service_config { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_fwaas_service_config { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
   neutron_l3_agent_config { 'DEFAULT/thisshouldexist' :
     value => 'foo',
   }
@@ -228,78 +185,6 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
-  neutron_plugin_cisco { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_plugin_cisco { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_plugin_cisco { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_cisco { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_cisco_credentials { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_plugin_cisco_credentials { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_plugin_cisco_credentials { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_cisco_credentials { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_cisco_db_conn { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_plugin_cisco_db_conn { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_plugin_cisco_db_conn { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_cisco_db_conn { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_cisco_l2network { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_plugin_cisco_l2network { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_plugin_cisco_l2network { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_cisco_l2network { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
   neutron_plugin_linuxbridge { 'DEFAULT/thisshouldexist' :
     value => 'foo',
   }
@@ -372,24 +257,6 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
-  neutron_plugin_midonet { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_plugin_midonet { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_plugin_midonet { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_midonet { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
   neutron_plugin_opencontrail { 'DEFAULT/thisshouldexist' :
     value => 'foo',
   }
@@ -444,41 +311,6 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
-  neutron_plugin_plumgrid { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_plugin_plumgrid { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_plugin_plumgrid { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plugin_plumgrid { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_plumlib_plumgrid { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_plumlib_plumgrid { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_plumlib_plumgrid { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto', }
-
-  neutron_plumlib_plumgrid { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
   neutron_plugin_nsx { 'DEFAULT/thisshouldexist' :
     value => 'foo',
   }
@@ -592,23 +424,16 @@ describe 'basic neutron_config resource' do
   resource_names = ['neutron_api_paste_ini',
                     'neutron_config',
                     'neutron_dhcp_agent_config',
-                    'neutron_fwaas_service_config',
                     'neutron_l3_agent_config',
                     'neutron_metadata_agent_config',
-                    'neutron_plugin_cisco',
-                    'neutron_plugin_cisco_credentials',
-                    'neutron_plugin_cisco_db_conn',
-                    'neutron_plugin_cisco_l2network',
                     'neutron_plugin_linuxbridge',
                     'neutron_metering_agent_config',
                     'neutron_plugin_ml2',
                     'neutron_plugin_nvp',
                     'neutron_vpnaas_agent_config',
-                    'neutron_plugin_midonet',
                     'neutron_plugin_opencontrail',
                     'neutron_agent_linuxbridge',
                     'neutron_agent_ovs',
-                    'neutron_plugin_plumgrid',
                     'neutron_plugin_sriov',
                     'neutron_sriov_agent_config',
                     'neutron_agent_vpp',
