@@ -30,6 +30,9 @@ describe 'neutron::agents::l3' do
     it { should contain_class('neutron::params') }
 
     it 'configures l3_agent.ini' do
+      should contain_neutron_l3_agent_config('DEFAULT/ha_vrrp_auth_type').with_ensure('absent')
+      should contain_neutron_l3_agent_config('DEFAULT/ha_vrrp_auth_password').with_ensure('absent')
+      should contain_neutron_l3_agent_config('DEFAULT/ha_vrrp_advert_int').with_ensure('absent')
       should contain_neutron_l3_agent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/interface_driver').with_value(p[:interface_driver])
       should contain_neutron_l3_agent_config('DEFAULT/handle_internal_only_routers').with_value('<SERVICE DEFAULT>')
@@ -41,6 +44,10 @@ describe 'neutron::agents::l3' do
       should contain_neutron_l3_agent_config('ovs/integration_bridge').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('agent/availability_zone').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('agent/extensions').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('agent/report_interval').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('network_log/rate_limit').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('network_log/burst_limit').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('network_log/local_output_log_base').with_value('<SERVICE DEFAULT>')
     end
 
     it 'passes purge to resource' do
@@ -106,7 +113,7 @@ describe 'neutron::agents::l3' do
       end
       it 'should configure VRRP' do
         should contain_neutron_l3_agent_config('DEFAULT/ha_vrrp_auth_type').with_value(p[:ha_vrrp_auth_type])
-        should contain_neutron_l3_agent_config('DEFAULT/ha_vrrp_auth_password').with_value(p[:ha_vrrp_auth_password])
+        should contain_neutron_l3_agent_config('DEFAULT/ha_vrrp_auth_password').with_value(p[:ha_vrrp_auth_password]).with_secret(true)
         should contain_neutron_l3_agent_config('DEFAULT/ha_vrrp_advert_int').with_value(p[:ha_vrrp_advert_int])
       end
     end
@@ -129,6 +136,26 @@ describe 'neutron::agents::l3' do
         should contain_neutron_l3_agent_config('agent/availability_zone').with_value(p[:availability_zone])
       end
     end
+
+    context 'with extensions in string' do
+      before :each do
+        params.merge!(:extensions => 'fip_qos,gateway_ip_qos,port_forwarding')
+      end
+
+      it 'configures extentions' do
+        should contain_neutron_l3_agent_config('agent/extensions').with_value('fip_qos,gateway_ip_qos,port_forwarding')
+      end
+    end
+
+    context 'with extensions in array' do
+      before :each do
+        params.merge!(:extensions => ['fip_qos', 'gateway_ip_qos', 'port_forwarding'])
+      end
+
+      it 'configures extentions' do
+        should contain_neutron_l3_agent_config('agent/extensions').with_value('fip_qos,gateway_ip_qos,port_forwarding')
+      end
+    end
   end
 
   shared_examples 'neutron::agents::l3 on Debian' do
