@@ -41,14 +41,15 @@ describe 'neutron::agents::ml2::ovs' do
 
     it 'configures plugins/ml2/openvswitch_agent.ini' do
       should contain_neutron_agent_ovs('agent/polling_interval').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('agent/report_interval').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/l2_population').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/arp_responder').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/drop_flows_on_start').with_value(p[:drop_flows_on_start])
-      should contain_neutron_agent_ovs('agent/extensions').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('agent/minimize_polling').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('agent/tunnel_csum').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('ovs/datapath_type').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('ovs/vhostuser_socket_dir').with_value(['<SERVICE DEFAULT>'])
+      should contain_neutron_agent_ovs('agent/extensions').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('agent/minimize_polling').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('agent/tunnel_csum').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/datapath_type').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/vhostuser_socket_dir').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/ovsdb_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_connect_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_request_timeout').with_value('<SERVICE DEFAULT>')
@@ -57,16 +58,25 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('securitygroup/firewall_driver').\
         with_value(p[:firewall_driver])
       should contain_neutron_agent_ovs('securitygroup/enable_security_group').\
-        with_value(['<SERVICE DEFAULT>'])
+        with_value('<SERVICE DEFAULT>')
       should_not contain_neutron_agent_ovs('securitygroup/permitted_ethertypes')
       should contain_neutron_agent_ovs('ovs/tunnel_bridge').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/local_ip').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/int_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/tun_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('agent/tunnel_types').with_ensure('absent')
+      should contain_neutron_agent_ovs('ovs/bridge_mac_table_size').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
-      should_not contain_neutron_agent_ovs('ovs/resource_provider_bandwidths')
-      should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value(['<SERVICE DEFAULT>'])
+      should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
+        with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/resource_provider_hypervisors').\
+        with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/resource_provider_default_hypervisor').\
+        with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('network_log/rate_limit').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('network_log/burst_limit').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('network_log/local_output_log_base').with_value('<SERVICE DEFAULT>')
     end
 
     it 'installs neutron ovs agent package' do
@@ -321,13 +331,23 @@ describe 'neutron::agents::ml2::ovs' do
       it { should raise_error(Puppet::Error, /Enabling DPDK without manage vswitch does not have any effect/) }
     end
 
-    context 'when resource_provider_bandwidths is set' do
+    context 'when parameters for resource providers are set' do
       before :each do
-        params.merge!(:resource_provider_bandwidths => ['provider-a', 'provider-b'])
+        params.merge!(
+          :resource_provider_bandwidths         => ['provider-a', 'provider-b'],
+          :resource_provider_hypervisors        => ['provider-a:compute-a', 'provider-b:compute-b'],
+          :resource_provider_default_hypervisor => 'compute-c',
+        )
       end
 
-      it { should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
-        with_value('provider-a,provider-b') }
+      it 'configures resource providers' do
+        should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
+          with_value('provider-a,provider-b')
+        should contain_neutron_agent_ovs('ovs/resource_provider_hypervisors').\
+          with_value('provider-a:compute-a,provider-b:compute-b')
+        should contain_neutron_agent_ovs('ovs/resource_provider_default_hypervisor').\
+          with_value('compute-c')
+      end
     end
 
   end
@@ -370,6 +390,16 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
+    context 'with mac table size on an ovs bridge set' do
+      before :each do
+        params.merge!(:bridge_mac_table_size => 50000)
+      end
+
+      it 'configure neutron/plugins/ml2/ml2_conf.ini' do
+        should contain_neutron_agent_ovs('ovs/bridge_mac_table_size').with_value(50000)
+      end
+    end
+
     context 'with IGMP snooping enabled' do
       before :each do
         params.merge!(:igmp_snooping_enable => true)
