@@ -38,6 +38,7 @@ describe 'neutron::agents::ml2::sriov' do
       should contain_neutron_sriov_agent_config('sriov_nic/physical_device_mappings').with_value('<SERVICE DEFAULT>')
       should contain_neutron_sriov_agent_config('agent/extensions').with_value(['<SERVICE DEFAULT>'])
       should contain_neutron_sriov_agent_config('agent/polling_interval').with_value(p[:polling_interval])
+      should contain_neutron_sriov_agent_config('agent/report_interval').with_value('<SERVICE DEFAULT>')
       should contain_neutron_sriov_agent_config('securitygroup/firewall_driver').with_value('noop')
     end
 
@@ -66,8 +67,13 @@ describe 'neutron::agents::ml2::sriov' do
       should contain_service('neutron-sriov-nic-agent-service').that_notifies('Anchor[neutron::service::end]')
     end
 
-    it 'does not configure resource_provider_bandwidths by default' do
-      should_not contain_neutron_sriov_agent_config('sriov_nic/resource_provider_bandwidths')
+    it 'does not configure resource provider parameters by default' do
+      should contain_neutron_sriov_agent_config('sriov_nic/resource_provider_bandwidths').\
+        with_value('<SERVICE DEFAULT>')
+      should contain_neutron_sriov_agent_config('sriov_nic/resource_provider_hypervisors').\
+        with_value('<SERVICE DEFAULT>')
+      should contain_neutron_sriov_agent_config('sriov_nic/resource_provider_default_hypervisor').\
+        with_value('<SERVICE DEFAULT>')
     end
 
     context 'when number_of_vfs is empty' do
@@ -134,14 +140,22 @@ describe 'neutron::agents::ml2::sriov' do
       end
     end
 
-    context 'when resource_provider_bandwidths is set' do
+    context 'when parameters for resource providers are set' do
       before :each do
-        params.merge!(:resource_provider_bandwidths => ['provider-a', 'provider-b'])
+        params.merge!(
+          :resource_provider_bandwidths         => ['provider-a', 'provider-b'],
+          :resource_provider_hypervisors        => ['provider-a:compute-a', 'provider-b:compute-b'],
+          :resource_provider_default_hypervisor => 'compute-c'
+        )
       end
 
-      it 'configures resource_provider_bandwidths' do
+      it 'configures resource providers' do
         should contain_neutron_sriov_agent_config('sriov_nic/resource_provider_bandwidths').\
           with_value('provider-a,provider-b')
+        should contain_neutron_sriov_agent_config('sriov_nic/resource_provider_hypervisors').\
+          with_value('provider-a:compute-a,provider-b:compute-b')
+        should contain_neutron_sriov_agent_config('sriov_nic/resource_provider_default_hypervisor').\
+          with_value('compute-c')
       end
     end
   end
