@@ -65,12 +65,30 @@ describe 'neutron::agents::ml2::vpp' do
       end
     end
 
+    context 'with the host parameter' do
+      before :each do
+        params.merge!(:host => 'myhost')
+      end
+      it 'should set the host parameter' do
+        should contain_neutron_agent_vpp('DEFAULT/host').with_value('myhost')
+      end
+    end
+
     context 'when supplying a physnet mapping' do
       before :each do
-        params.merge!(:physnets => 'physnet:GigabitEthernet2/2/0')
+        params.merge!(:physnets => 'physnet0:GigabitEthernet2/2/0,physnet1:GigabitEthernet2/2/1')
       end
       it 'should configure physnets' do
-        should contain_neutron_agent_vpp('ml2_vpp/physnets').with_value('physnet:GigabitEthernet2/2/0')
+        should contain_neutron_agent_vpp('ml2_vpp/physnets').with_value('physnet0:GigabitEthernet2/2/0,physnet1:GigabitEthernet2/2/1')
+      end
+    end
+
+    context 'when supplying a physnet mapping in array' do
+      before :each do
+        params.merge!(:physnets => ['physnet0:GigabitEthernet2/2/0', 'physnet1:GigabitEthernet2/2/1'])
+      end
+      it 'should configure physnets' do
+        should contain_neutron_agent_vpp('ml2_vpp/physnets').with_value('physnet0:GigabitEthernet2/2/0,physnet1:GigabitEthernet2/2/1')
       end
     end
 
@@ -100,18 +118,8 @@ describe 'neutron::agents::ml2::vpp' do
           { :vpp_plugin_package => 'python3-networking-vpp',
             :vpp_agent_service  => 'neutron-vpp-agent' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :vpp_plugin_package => 'python3-networking-vpp',
-              :vpp_agent_service  => 'neutron-vpp-agent' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :vpp_plugin_package => 'python3-networking-vpp',
-                :vpp_agent_service  => 'neutron-vpp-agent' }
-            else
-              { :vpp_plugin_package => 'python-networking-vpp',
-                :vpp_agent_service  => 'neutron-vpp-agent' }
-            end
-          end
+          { :vpp_plugin_package => 'python3-networking-vpp',
+            :vpp_agent_service  => 'neutron-vpp-agent' }
         end
       end
 
