@@ -120,18 +120,8 @@ describe 'neutron::agents::ovn_metadata' do
             :ovn_metadata_agent_service => 'networking-ovn-metadata-agent'
           }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :ovn_metadata_agent_package => 'python3-networking-ovn-metadata-agent',
-              :ovn_metadata_agent_service => 'networking-ovn-metadata-agent' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :ovn_metadata_agent_package => 'python3-networking-ovn-metadata-agent',
-                :ovn_metadata_agent_service => 'networking-ovn-metadata-agent' }
-            else
-              { :ovn_metadata_agent_package => 'python-networking-ovn-metadata-agent',
-                :ovn_metadata_agent_service => 'networking-ovn-metadata-agent' }
-            end
-          end
+          { :ovn_metadata_agent_package => 'python3-networking-ovn-metadata-agent',
+            :ovn_metadata_agent_service => 'networking-ovn-metadata-agent' }
         end
       end
 
