@@ -56,7 +56,9 @@ describe 'neutron::config' do
 
   shared_examples 'neutron_agent_config' do
     let :params do
-      { :l3_agent_config       => config_hash,
+      { :ovs_agent_config      => config_hash,
+        :sriov_agent_config    => config_hash,
+        :l3_agent_config       => config_hash,
         :dhcp_agent_config     => config_hash,
         :metadata_agent_config => config_hash,
         :metering_agent_config => config_hash,
@@ -66,6 +68,18 @@ describe 'neutron::config' do
       }
     end
 
+    it 'configures arbitrary neutron_ovs_agent_config configurations' do
+      should contain_neutron_agent_ovs('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_agent_ovs('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_agent_ovs('DEFAULT/baz').with_ensure('absent')
+    end
+
+    it 'configures arbitrary neutron_sriov_agent_config configurations' do
+      should contain_neutron_sriov_agent_config('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_sriov_agent_config('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_sriov_agent_config('DEFAULT/baz').with_ensure('absent')
+    end
+
     it 'configures arbitrary l3_agent_config configurations' do
       should contain_neutron_l3_agent_config('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_l3_agent_config('DEFAULT/bar').with_value('barValue')
@@ -114,11 +128,6 @@ describe 'neutron::config' do
     let :params do
       {
         :plugin_linuxbridge_config     => config_hash,
-        :plugin_cisco_db_conn_config   => config_hash,
-        :plugin_cisco_l2network_config => config_hash,
-        :plugin_cisco_config           => config_hash,
-        :plugin_midonet_config         => config_hash,
-        :plugin_plumgrid_config        => config_hash,
         :plugin_nsx_config             => config_hash,
         :plugin_nvp_config             => config_hash,
         :plugin_opencontrail_config    => config_hash,
@@ -133,36 +142,6 @@ describe 'neutron::config' do
       should contain_neutron_plugin_linuxbridge('DEFAULT/baz').with_ensure('absent')
     end
 
-    it 'configures arbitrary neutron_plugin_cisco_db_conn configurations' do
-      should contain_neutron_plugin_cisco_db_conn('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_cisco_db_conn('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_cisco_db_conn('DEFAULT/baz').with_ensure('absent')
-    end
-
-    it 'configures arbitrary neutron_plugin_cisco_l2network configurations' do
-      should contain_neutron_plugin_cisco_l2network('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_cisco_l2network('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_cisco_l2network('DEFAULT/baz').with_ensure('absent')
-    end
-
-    it 'configures arbitrary neutron_plugin_cisco configurations' do
-      should contain_neutron_plugin_cisco('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_cisco('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_cisco('DEFAULT/baz').with_ensure('absent')
-    end
-
-    it 'configures arbitrary neutron_plugin_midonet configurations' do
-      should contain_neutron_plugin_midonet('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_midonet('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_midonet('DEFAULT/baz').with_ensure('absent')
-    end
-
-    it 'configures arbitrary neutron_plugin_plumgrid configurations' do
-      should contain_neutron_plugin_plumgrid('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_plugin_plumgrid('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_plugin_plumgrid('DEFAULT/baz').with_ensure('absent')
-    end
-
     it 'configures arbitrary neutron_plugin_nsx configurations' do
       should contain_neutron_plugin_nsx('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_plugin_nsx('DEFAULT/bar').with_value('barValue')
@@ -205,6 +184,7 @@ describe 'neutron::config' do
 
       it_behaves_like 'neutron_config'
       it_behaves_like 'neutron_api_paste_ini'
+      it_behaves_like 'neutron_service_config'
       it_behaves_like 'neutron_agent_config'
       it_behaves_like 'neutron_plugin_config'
     end
