@@ -12,6 +12,7 @@ describe 'neutron::db' do
         :retry_interval          => '<SERVICE DEFAULT>',
         :max_overflow            => '<SERVICE DEFAULT>',
         :pool_timeout            => '<SERVICE DEFAULT>',
+        :mysql_enable_ndb        => '<SERVICE DEFAULT>',
       )}
     end
 
@@ -26,6 +27,7 @@ describe 'neutron::db' do
           :database_db_max_retries          => '-1',
           :database_max_overflow            => '21',
           :database_pool_timeout            => '21',
+          :mysql_enable_ndb                 => true,
         }
       end
 
@@ -38,6 +40,7 @@ describe 'neutron::db' do
         :retry_interval          => '11',
         :max_overflow            => '21',
         :pool_timeout            => '21',
+        :mysql_enable_ndb        => true,
       )}
     end
   end
