@@ -34,7 +34,7 @@ describe provider_class do
 
   let (:provider) { resource.provider }
 
-  [ 'RedHat', 'Debian' ].each do |os|
+  [ 'RedHat', 'Debian', 'Ubuntu' ].each do |os|
     context "on #{os} with default setting" do
       it 'it should fall back to default and use plugins/ml2/openvswitch_agent.ini' do
         Facter.fact(:operatingsystem).stubs(:value).returns("#{os}")
@@ -44,13 +44,4 @@ describe provider_class do
       end
     end
   end
-
-  context 'on Ubuntu with default setting' do
-    it 'it should fall back to default and use ml2_conf.ini' do
-      Facter.fact(:operatingsystem).stubs(:value).returns('Ubuntu')
-      expect(provider.section).to eq('DEFAULT')
-      expect(provider.setting).to eq('foo')
-      expect(provider.file_path).to eq('/etc/neutron/plugins/ml2/ml2_conf.ini')
-    end
-  end
 end
